@@ -7,7 +7,7 @@ class AddressProvider(object):
         super(AddressProvider, self).__init__()
 
     def generate_address(self, obj):
-        return str(hash(obj))
+        return str(hash(obj))  + "." + socket.gethostname() + "." + str(os.getpid())
 
 
 class Addressable(object):
@@ -17,4 +17,7 @@ class Addressable(object):
         if hasattr(self, "name") and self.name:
             self.address = self.name + "." + socket.gethostname() + "." + str(os.getpid())
         else:
-            self.address = self.address_provider.generate_address(self)
\ No newline at end of file
+            self.address = self.address_provider.generate_address(self)
+
+    def get_address(self):
+        return self.address
\ No newline at end of file
